@@ -1,9 +1,14 @@
 # Natural spline, parameterized so that the coefficients are the values of the
 #  spline at the knots.
+# As of 1/2026 this is deprecated, the splines2 package has a version with
+#  better error checks, and that is really where this belongs in any case.
 #
 nsk <- function(x, df=NULL, knots=NULL, intercept=FALSE, b=.05,
                 Boundary.knots = quantile(x, c(b, 1-b), na.rm=TRUE)) {
 
+#    .Deprecated("nsk", "splines2", 
+#                "this function has been moved to a more appropriate package")
+#    
     if (is.logical(Boundary.knots)) {
         if (Boundary.knots) Boundary.knots <- range(x, na.rm=TRUE) # ns default
         else Boundary.knots <- NULL
@@ -30,6 +35,19 @@ nsk <- function(x, df=NULL, knots=NULL, intercept=FALSE, b=.05,
     else basis <- ns(x, df=df, knots= iknot, intercept=intercept,
                    Boundary.knots = bknot)
     iknot <- attr(basis, "knots")
+    
+    temp <- c(bknot, iknot)
+    if (any(duplicated(temp))) {
+        # duplicate knots not allowed, but can occur in ns if there are a
+        #  lot of ties near one end
+        temp <- unique(temp)
+        if (length(temp)==2) 
+             basis <- ns(x, intercept=intercept, Boundary.knots = bknot)
+        else basis <- ns(x, intercept=intercept, Boundary.knots = bknot,
+                         knots = temp[-(1:2)])
+       iknot <- attr(basis, "knots")
+    }     
+            
     kx <- c(bknot[1], iknot, bknot[2])
     kbasis <- ns(kx, df=df, knots=iknot, intercept=intercept,
                  Boundary.knots = bknot)         
@@ -49,7 +67,7 @@ nsk <- function(x, df=NULL, knots=NULL, intercept=FALSE, b=.05,
 
 makepredictcall.nsk <- function(var, call)
 {
-    if(as.character(call)[1L] == "nsk" || 
+    if (as.character(call)[1L] == "nsk" || 
        (is.call(call) && identical(eval(call[[1L]]), nsk))) {
 	at <- attributes(var)[c("knots", "Boundary.knots", "intercept")]
 	call <- call[1L:2L]
