@@ -1,6 +1,6 @@
 survSplit <- function(formula, data, subset, na.action=na.pass,
                               cut, start="tstart", id, zero=0, episode,
-                              end="tstop", event="event") {
+                              end="tstop", event="event", added) {
     Call <- match.call()
     if (missing(formula) || is.data.frame(formula)) {
         # an old style call
@@ -62,7 +62,7 @@ survSplit <- function(formula, data, subset, na.action=na.pass,
         
     if (!is.numeric(cut) || any(!is.finite(cut)))
         stop("cut must be a vector of finite numbers")
-    cut <- sort(cut)
+    cut <- unique(sort(cut))
     ntimes <- length(cut)
     n <- nrow(data)
 
@@ -82,8 +82,10 @@ survSplit <- function(formula, data, subset, na.action=na.pass,
 
     status <- Y[index$row, 3]
     status[index$censor] <- 0
+    # the factor line needs 0:length(states) in case there is a state
+    #  with no event, then status will be missing a category
     if (!is.null(states))  
-        status <- factor(status, labels=c("censor", states))
+        status <- factor(status, 0:length(states),labels=c("censor", states))
 
     # Did the user hand me a Surv call with multiple variables, or a
     #  premade Surv object?
@@ -120,7 +122,7 @@ survSplit <- function(formula, data, subset, na.action=na.pass,
         newdata[[event]] <- status
     }
     else {
-        if (class(formula[[2]]) != "name")
+        if (!inherits(formula[[2]], "name"))
             stop("left hand side not recognized")
         temp <- as.character(formula[[2]])
         newdata[temp] <- Surv(index$start, index$end, status)
@@ -130,5 +132,9 @@ survSplit <- function(formula, data, subset, na.action=na.pass,
         if (!is.character(episode)) stop("episode must be a character string")
         newdata[[make.names(episode)]] <- index$interval +1
     }
+    if (!missing(added)) {
+        if (!is.character(added)) stop("added must be a character string")
+        newdata[[make.names(added)]] <- index$censor
+    }
     newdata
 }
